#
# spec file for package khtml
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5KHtml5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           khtml
Version:        5.116.0
Release:        1.3
Summary:        HTML rendering engine
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  giflib-devel
BuildRequires:  gperf
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Archive) >= %{_kf5_version}
BuildRequires:  cmake(KF5Codecs) >= %{_kf5_version}
BuildRequires:  cmake(KF5GlobalAccel) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5IconThemes) >= %{_kf5_version}
BuildRequires:  cmake(KF5JS) >= %{_kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_version}
BuildRequires:  cmake(KF5Notifications) >= %{_kf5_version}
BuildRequires:  cmake(KF5Parts) >= %{_kf5_version}
BuildRequires:  cmake(KF5Sonnet) >= %{_kf5_version}
BuildRequires:  cmake(KF5TextWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5Wallet) >= %{_kf5_version}
BuildRequires:  cmake(KF5WidgetsAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{_kf5_version}
BuildRequires:  cmake(KF5XmlGui) >= %{_kf5_version}
BuildRequires:  cmake(Phonon4Qt5)
BuildRequires:  cmake(Qt5Core) >= %{qt5_version}
BuildRequires:  cmake(Qt5DBus) >= %{qt5_version}
BuildRequires:  cmake(Qt5Network) >= %{qt5_version}
BuildRequires:  cmake(Qt5PrintSupport) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5X11Extras) >= %{qt5_version}
BuildRequires:  cmake(Qt5Xml) >= %{qt5_version}
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(x11)

%description
KHTML is a web rendering engine, based on the KParts
technology and using KJS for JavaScript support.

%package -n %{lname}
Summary:        HTML rendering engine
Obsoletes:      libKF5KHtml4

%description -n %{lname}
KHTML is a web rendering engine, based on the KParts
technology and using KJS for JavaScript support.

%package devel
Summary:        HTML rendering engine
Requires:       %{lname} = %{version}
Requires:       cmake(KF5Codecs) >= %{_kf5_version}
Requires:       cmake(KF5I18n) >= %{_kf5_version}
Requires:       cmake(KF5JS) >= %{_kf5_version}
Requires:       cmake(KF5KIO) >= %{_kf5_version}
Requires:       cmake(KF5Parts) >= %{_kf5_version}
Requires:       cmake(KF5TextWidgets) >= %{_kf5_version}
Requires:       cmake(Qt5Gui) >= %{qt5_version}

%description devel
KHTML is a web rendering engine, based on the KParts
technology and using KJS for JavaScript support.
Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
%ifarch ppc64
%define _lto_cflags %{nil}
%endif

%cmake_kf5 -d build -- -DSYSCONF_INSTALL_DIR=%{_kf5_sysconfdir}
%cmake_build

%install
%kf5_makeinstall -C build
%fdupes %{buildroot}


%find_lang khtml5

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}-lang -f khtml5.lang

%files -n %{lname}
%license COPYING*
%doc README*
%{_kf5_libdir}/libKF5KHtml.so.*
%{_kf5_plugindir}/
%{_kf5_servicesdir}/
%{_kf5_datadir}/khtml/
%config %{_kf5_configdir}/khtmlrc
%{_kf5_debugdir}/*.categories
%{_kf5_debugdir}/*.renamecategories

%files devel
%{_kf5_libdir}/libKF5KHtml.so
%{_kf5_libdir}/cmake/KF5KHtml/
%{_kf5_includedir}/KHtml/
%{_kf5_mkspecsdir}/qt_KHtml.pri

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- No code change since 5.110.0
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- No code change since 5.107.0
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- No code change since 5.105.0
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- No code change since 5.103.0
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * fix clang build: error: invalid operands to binary expression
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- No code change since 5.100.0
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- No code change since 5.99.0
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- No code change since 5.98.0
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Add CMake option to build WITH_X11
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- No code change since 5.96.0
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- No code change since 5.95.0
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * java remove support for Java applets
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- Changes since 5.92.0:
  * Build without kglobalaccel on Windows and mac
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- No code change since 5.91.0
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * fix khtml crash in wayland session
  * [ci] Fix phonon dep
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- No code change since 5.89.0
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- No code change since 5.88.0
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Add FreeBSD CI
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Changes since 5.85.0:
  * We more lenient in reading QImages (kde#441501)
* Fri Aug 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Disable lto for ppc64 builds.
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- No code change since 5.84.0
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- No code change since 5.83.0
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Bump required CMake version to 3.16
  * Call ki18n_install() unconditionally
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Remove usage of the register keyword
  * Let gperf generate C++ code
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- No code change since 5.80.0
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- No code change since 5.79.0
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- No code change since 5.78.0
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Don't include QtTest as it includes all QtCore includes
  * operator+/- is disabled for QFlags in qt6
* Sat Dec  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- No code change since 5.76.0
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- No code change since 5.74.0
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- No code change since 5.73.0
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- No code change since 5.71.0
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- No code change since 5.70.0
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- No code change since 5.69.0
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- No code change since 5.68.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- No code change since 5.66.0
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Port some deprecated methods
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- No code change since 5.64.0
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Extend KHtmlView::print() to use a predefined QPrinter instance (kde#405011)
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- No code change since 5.62.0
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- No code change since 5.61.0
- Replace foo-devel with cmake(KF5Foo) in build requirements
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- No code change since 5.60.0
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- No code changes since 5.58.0
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- No code changes since 5.57.0
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Remove deprecated methods
  * Fix port to std::sort
  * Port setMargin to setContentsMargins
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * No code changes since 5.55.0
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * Fix ui.rc files to use non-deprecated <gui> root
  * Add JSON metadata to khtmlpart plugin binary
  * Use more https in links
  * Avoid warnings for "this use of "defined" may not be portable"
  * Use more nullptr
  * Port away from deprecated KFilterDev::device()
  * Port away from deprecated KWindowSystem::windowInfo()
  * Port to non-deprecated variant of KRun::runUrl
  * Remove defunct call of K_EXPORT_PLUGIN
  * Port away from deprecated kservice_desktop_to_json
  * Port away from deprecated KTextEdit::setClickMessage
  * Port away from deprecated KLineEdit::isClearButtonShown/setClearButtonShown
  * Port deprecated QStyleOptionFrameV3 -> QStyleOptionFrame
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Fix mem leak
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use new syntax
  * Remove qt include prefix
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * No code changes since 5.51.0
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * No code changes since 5.50.0
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * None
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * None
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Use override
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Use override
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * None
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * avoid asking for an empty protocol
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * None
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Install khtml_debug.h
  * Remove some debug.h in header
  * Fix cmake warning
  * Finally allow to disable debug
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * None
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Remove the final endl at the end of qDebug &co
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * None
* Sun Aug 13 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Support SVG too (kde#355872)
- Drop 0001-Support-SVG-too.patch (merged upstream)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * tests: missed one source for kencodingdetectortest
  * cmake: use ecm_add_test more
* Mon Jul 10 2017 wbauer@tmo.at
- Add 0001-Support-SVG-too.patch to make Konqueror's startup page
  show icons with the breeze theme (boo#1011092, kde#355872)
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Generate kentities gperf output at build time
  * Pass `--key-positions=*` to gperf instead of `-k *` because on Windows this symbol seems to have a special meaning.
  * Generate doctypes gperf output at build time
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Fix build with Qt 5.9 (kde#377490)
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Error page, correctly load the image (with a real URL)
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * java: apply the names to the right buttons
  * java: set names in permission dialog
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * Support percentage unit in border radius
  * Removed prefixed version of background and
    border radius properties
  * Fixes in 4-values shorthand constructor function
  * Create string objects only if they will be used
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Fix applying inherit value for outline shorthand property
  * Handle initial and inherit for border radius
  * Discard property if we caught an invalid length|percent
    as background-size
  * cssText must output comma separated values for those properties
  * Fix parsing background-clip in shorthand
  * Implement background-size parsing in shorthand
  * Mark properties as set when repeating patterns
  * Fix background properties inheritance
  * Fix applying Initial and Inherit for background-size property
  * Deploy the khtml kxmlgui file in a Qt resource file
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Fix potential memory leak reported by Coverity and
    simplify the code
  * The number of layers is determined by the number of
    comma-separated values in the ‘background-image’ property
  * Fix parsing background-position in shorthand declaration
  * Do not create new fontFace if there is no valid source
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Implement toString for Uint8ArrayConstructor and friends
  * Merge in several Coverity-related fixes
  * Correctly use QCache::insert
  * Fix some memory leaks
  * Sanity check CSS web font parsing, avoid potential mem leak
  * dom: Add tag priorities for 'comment' tag
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Fix cursor updating in view
  * Limit string memory use
  * KHTML java applet viewer: repair broken DBus call to kpasswdserver
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Fix detection of icon link type (aka "favicon")
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Windows: remove kdewin dependency
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Fix printing from KHTMLPart by correctly setting printSetting parent
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Replace std::auto_ptr with std::unique_ptr
  * khtml-filter: Discard rules containing special adblock features
    that we do not handle yet.
  * khtml-filter: Code reorder, no functional changes.
  * khtml-filter: Ignore regexp with options as we do
    not support them.
  * khtml-filter: Fix detection of adblock options delimiter.
  * khtml-filter: Clean up from trailing white spaces.
  * khtml-filter: Do not discard lines starting with '&' as it
    is not a special adblock char.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Let KHtml be useable w/o searching for private deps
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * 6 bug fixes forward-ported from kdelibs4.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * A number of forward-ported fixes from kdelibs, no API changes.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
- Drop 0001-Fix-build-with-giflib-5.1.patch, merged upstream
* Mon Jun 16 2014 hrvoje.senjan@gmail.com
- Added 0001-Fix-build-with-giflib-5.1.patch from upstream
* Wed Jun 11 2014 hrvoje.senjan@gmail.com
- Simplify filelist (also makes dir ownership more correct)
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init khtml package
